/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id$
 * --------------------------------------------------------------------------
 */

package org.ow2.util.scan.impl;

import org.ow2.util.archive.api.IArchive;
import org.ow2.util.scan.api.ArchiveScanner;
import org.ow2.util.scan.api.ArchiveScannerFactory;
import org.ow2.util.scan.api.IArchiveHelper;

/**
 * Reference Implementation of API. You may use
 * ArchiveScannerFactory.getReferenceImplementationInstance() instead of
 * ArchiveScannerFactoryImpl.getInstance()
 * @author Gael Lalire
 */
public final class ArchiveScannerFactoryImpl extends ArchiveScannerFactory {

    /**
     * Constructor.
     */
    public ArchiveScannerFactoryImpl() {
    }

    /**
     * create an archive scanner.
     * @param archive the archive to scan
     * @return an archive scanner
     */
    @Override
    public ArchiveScanner createArchiveScanner(final IArchive archive) {
        return new ArchiveScannerImpl(archive);
    }

    /**
     * Construct an archive scanner with an archive.
     * @param archiveHelper archive helper
     * @return a new archive scanner
     */
    @Override
    public ArchiveScanner createArchiveScanner(final IArchiveHelper archiveHelper) {
        return new ArchiveScannerImpl(archiveHelper);
    }

}
